@@ -2,8 +2,7 @@ use std::collections::BTreeMap;
 use std::io::Cursor;
 use std::io::Error;
 
-use fluvio_protocol_core::{Decoder, Encoder};
-use fluvio_protocol_derive::{Decoder, Encoder};
+use fluvio_protocol::{Decoder, Encoder};
 
 #[derive(Encoder, Default, Decoder, Debug)]
 pub struct MapHolder {
